import { expect, tap } from '@pushrocks/tapbundle';
import * as smartsmtp from '../ts/index';

import { Qenv } from '@pushrocks/qenv';
import * as smartmail from '@pushrocks/smartmail';

const testQenv = new Qenv('./', './.nogit');

let testSmartsmtp: smartsmtp.Smartsmtp;

tap.test('should create a valid instance of Smartsmtp', async () => {
  testSmartsmtp = await smartsmtp.Smartsmtp.createSmartsmtpWithRelay({
    smtpServer: testQenv.getEnvVarOnDemand('SMTP_SERVER'),
    smtpUser: testQenv.getEnvVarOnDemand('SMTP_USER'),
    smtpPassword: testQenv.getEnvVarOnDemand('SMTP_PASSWORD'),
  });
  expect(testSmartsmtp).to.be.instanceOf(smartsmtp.Smartsmtp);
});

tap.test('should send a message with empty body', async () => {
  const result = await testSmartsmtp.sendSmartMail(
    new smartmail.Smartmail({
      body: '',
      from: 'smartsmtp@mail.lossless.one',
      subject: 'this is a test message',
    }),
    'sandbox@mail.git.zone'
  );
  console.log(result);
});

tap.test('should create a direct smartsmtp transport', async () => {
  const smartsmtpInstance = await smartsmtp.Smartsmtp.createSmartsmtpSendmail();
  const result = await smartsmtpInstance.sendSmartMail(
    new smartmail.Smartmail({
      body: 'hi there',
      from: 'phil@lossless.com',
      subject: 'this is a sendmail test message',
    }),
    'phil@kunz.io'
  );
  console.log(result);
})

tap.start();
